==> classpath-0.06.tar.gz: classpath-0.06/javax/print/attribute/AttributeSet.java <==
/* AttributeSet.java -- 
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.print.attribute;

/**
 * @author Michael Koch
 */
public interface AttributeSet
{
  /**
   * Adds the specified attribute value to this attribute set
   * if it is not already present.
   */
  public boolean add (Attribute attribute);

  /**
   * Adds all of the elements in the specified set to this attribute.
   */
  public boolean addAll (AttributeSet attributes);

  public void clear ();

  public boolean containsKey (Class category);

  public boolean containsValue (Attribute attribute);
  
  public boolean equals (Object obj);

  public Attribute get (Class Category);

  public int hashCode ();

  public boolean isEmpty ();

  public boolean remove (Attribute attribute);

  public boolean remove (Class category);

  public int size ();

  public Attribute[] toArray ();
}

==> classpath-0.10.tar.gz: classpath-0.10/javax/print/attribute/AttributeSet.java <==
/* AttributeSet.java -- 
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.print.attribute;

/**
 * @author Michael Koch
 */
public interface AttributeSet
{
  /**
   * Adds the specified attribute value to this attribute set
   * if it is not already present.
   */
  boolean add (Attribute attribute);

  /**
   * Adds all of the elements in the specified set to this attribute.
   */
  boolean addAll (AttributeSet attributes);

  void clear ();

  boolean containsKey (Class category);

  boolean containsValue (Attribute attribute);
  
  boolean equals (Object obj);

  Attribute get (Class Category);

  int hashCode ();

  boolean isEmpty ();

  boolean remove (Attribute attribute);

  boolean remove (Class category);

  int size ();

  Attribute[] toArray ();
}
